# Python MVC Shell Framework Package

## Changelog

This is a non-exhaustive (but still near complete) changelog for PMVCS.

```
Legend:

* -> Security Fix
# -> Bug Fix
+ -> Addition
^ -> Change
- -> Removed
! -> Note
```


```
1.0.2-dev ---> 	None yet.

1.0.1 ---> 	^ Modified core decorators' views to by pass args and kwargs
			# Translated one spanish constant in es.ini (ERROR: Unknown format)
			+ Added how to use configuration/language/view functions in documentation.
			+ Added changelog in markdown format.
```

```
1.0.0 ---> 	Initial release
```
